@@ -1,7 +1,7 @@
 #pragma once
 
-#include <stdbool.h>
 #include <stdint.h>
+#include <stdbool.h>
 
 #include "decode.h"
 #include "encodings_dec.h"
@@ -15,9 +15,8 @@
 //-----------------------------------------------------------------------------
 
 /* these get returned by the disassemble_instruction() function */
-enum FailureCode
-{
-	DISASM_SUCCESS = 0,
+enum FailureCode {
+	DISASM_SUCCESS=0,
 	INVALID_ARGUMENTS,
 	FAILED_TO_DISASSEMBLE_OPERAND,
 	FAILED_TO_DISASSEMBLE_OPERATION,
@@ -29,24 +28,27 @@ enum FailureCode
 };
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
-	// get a text representation of the decomposed instruction
-	int aarch64_disassemble(Instruction* instruction, char* buf, size_t buf_sz);
+// get a text representation of the decomposed instruction
+int aarch64_disassemble(Instruction *instruction, char *buf, size_t buf_sz);
 
-	// register (and related) to string
-	int get_register_full(enum Register, const InstructionOperand*, char* result);
-	const char* get_register_arrspec(enum Register, const InstructionOperand*);
+// register (and related) to string
+int get_register_full(enum Register, const InstructionOperand *, char *result);
+const char *get_register_arrspec(enum Register, const InstructionOperand *);
 
-	// miscellany to string
-	const char* get_operation(const Instruction* instruction);
-	const char* get_shift(ShiftType shift);
-	const char* get_condition(Condition cond);
-	uint32_t get_implementation_specific(
-	    const InstructionOperand* operand, char* outBuffer, uint32_t outBufferSize);
+// miscellany to string
+const char *get_operation(const Instruction *instruction);
+const char *get_shift(ShiftType shift);
+const char *get_condition(Condition cond);
+uint32_t get_implementation_specific(
+		const InstructionOperand *operand,
+		char *outBuffer,
+		uint32_t outBufferSize);
 
 #ifdef __cplusplus
 }
 #endif
+
+
